@@ -32,6 +32,8 @@
 #include "gegl-tile-storage.h"
 #include "gegl-utils.h"
 
+#include "gegl-buffer-cl-cache.h"
+
 typedef struct GeglBufferTileIterator
 {
   GeglBuffer    *buffer;
@@ -52,7 +54,8 @@ typedef struct GeglBufferTileIterator
   GeglRectangle  roi2;     /* the rectangular subregion of data
                             * in the buffer represented by this scan.
                             */
-
+  gboolean       same_format;
+  gint           level;
 } GeglBufferTileIterator;
 
 #define GEGL_BUFFER_SCAN_COMPATIBLE   128   /* should be integrated into enum */
@@ -84,7 +87,9 @@ typedef struct GeglBufferIterators
 static void      gegl_buffer_tile_iterator_init (GeglBufferTileIterator *i,
                                                  GeglBuffer             *buffer,
                                                  GeglRectangle           roi,
-                                                 gboolean                write);
+                                                 gboolean                write,
+                                                 const Babl             *format,
+                                                 gint                    level);
 static gboolean  gegl_buffer_tile_iterator_next (GeglBufferTileIterator *i);
 
 /*
@@ -116,23 +121,30 @@ static gboolean gegl_buffer_scan_compatible (GeglBuffer *bufferA,
 static void gegl_buffer_tile_iterator_init (GeglBufferTileIterator *i,
                                             GeglBuffer             *buffer,
                                             GeglRectangle           roi,
-                                            gboolean                write)
+                                            gboolean                write,
+                                            const Babl             *format,
+                                            gint                    level)
 {
   g_assert (i);
   memset (i, 0, sizeof (GeglBufferTileIterator));
-  if (roi.width == 0 ||
-      roi.height == 0)
-    g_error ("eeek");
+
   i->buffer = buffer;
   i->roi = roi;
+  i->level = level;
   i->next_row    = 0;
   i->next_col = 0;
   i->tile = NULL;
   i->col = 0;
   i->row = 0;
   i->write = write;
+  
   i->max_size = i->buffer->tile_storage->tile_width *
                 i->buffer->tile_storage->tile_height;
+
+  i->same_format = format == buffer->format;
+
+  /* return at the end,. we still want things initialized a bit .. */
+  g_return_if_fail (roi.width != 0 && roi.height != 0);
 }
 
 static gboolean
@@ -154,7 +166,7 @@ gulp:
   /* unref previously held tile */
   if (i->tile)
     {
-      if (i->write && i->subrect.width == tile_width)
+      if (i->write && i->subrect.width == tile_width && i->same_format)
         {
           gegl_tile_unlock (i->tile);
         }
@@ -183,19 +195,20 @@ gulp:
            i->subrect.height = tile_height - offsety;
 
          i->tile = gegl_tile_source_get_tile ((GeglTileSource *) (buffer),
-                                               gegl_tile_indice (tiledx, tile_width),
-                                               gegl_tile_indice (tiledy, tile_height),
-                                               0);
-         if (i->write && tile_width==i->subrect.width)
+                                        gegl_tile_indice (tiledx, tile_width),
+                                        gegl_tile_indice (tiledy, tile_height),
+                                        0);
+         if (i->write && i->subrect.width == tile_width && i->same_format)
            {
              gegl_tile_lock (i->tile);
            }
          i->data = gegl_tile_get_data (i->tile);
 
          {
-         gint bpp = babl_format_get_bytes_per_pixel (i->buffer->format);
+         gint bpp = babl_format_get_bytes_per_pixel (i->buffer->soft_format);
          i->rowstride = bpp * tile_width;
-         i->sub_data = (guchar*)(i->data) + bpp * (i->subrect.y * tile_width + i->subrect.x);
+         i->sub_data = (guchar*)(i->data) + bpp * 
+                        (i->subrect.y * tile_width + i->subrect.x);
          }
 
          i->col = i->next_col;
@@ -241,12 +254,15 @@ static glong in_direct_read = 0;
 static glong in_direct_write = 0;
 #endif
 
+
 gint
 gegl_buffer_iterator_add (GeglBufferIterator  *iterator,
                           GeglBuffer          *buffer,
                           const GeglRectangle *roi,
+                          gint                 level,
                           const Babl          *format,
-                          guint                flags)
+                          guint                flags,
+                          GeglAbyssPolicy      abyss_policy)
 {
   GeglBufferIterators *i = (gpointer)iterator;
   gint self = 0;
@@ -260,6 +276,10 @@ gegl_buffer_iterator_add (GeglBufferIterator  *iterator,
       memset (i, 0, sizeof (GeglBufferIterators));
     }
 
+  /* XXX: should assert that the passed in level matches
+   * the level of the base iterator.
+   */
+
   self = i->iterators++;
 
   if (!roi)
@@ -271,13 +291,13 @@ gegl_buffer_iterator_add (GeglBufferIterator  *iterator,
   if (format)
     i->format[self]=format;
   else
-    i->format[self]=buffer->format;
+    i->format[self]=buffer->soft_format;
   i->flags[self]=flags;
 
   if (self==0) /* The first buffer which is always scan aligned */
     {
       i->flags[self] |= GEGL_BUFFER_SCAN_COMPATIBLE;
-      gegl_buffer_tile_iterator_init (&i->i[self], i->buffer[self], i->rect[self], ((i->flags[self] & GEGL_BUFFER_WRITE) != 0) );
+      gegl_buffer_tile_iterator_init (&i->i[self], i->buffer[self], i->rect[self], ((i->flags[self] & GEGL_BUFFER_WRITE) != 0), i->format[self], iterator->level);
     }
   else
     {
@@ -289,13 +309,13 @@ gegl_buffer_iterator_add (GeglBufferIterator  *iterator,
                                        i->buffer[self], i->rect[self].x, i->rect[self].y))
         {
           i->flags[self] |= GEGL_BUFFER_SCAN_COMPATIBLE;
-          gegl_buffer_tile_iterator_init (&i->i[self], i->buffer[self], i->rect[self], ((i->flags[self] & GEGL_BUFFER_WRITE) != 0));
+          gegl_buffer_tile_iterator_init (&i->i[self], i->buffer[self], i->rect[self], ((i->flags[self] & GEGL_BUFFER_WRITE) != 0), i->format[self], iterator->level);
         }
     }
 
   i->buf[self] = NULL;
 
-  if (i->format[self] == i->buffer[self]->format)
+  if (i->format[self] == i->buffer[self]->soft_format)
     {
       i->flags[self] |= GEGL_BUFFER_FORMAT_COMPATIBLE;
     }
@@ -303,7 +323,7 @@ gegl_buffer_iterator_add (GeglBufferIterator  *iterator,
 }
 
 /* FIXME: we are currently leaking this buf pool, it should be
- * freeing it when gegl is uninitialized
+ * freed when gegl is uninitialized
  */
 
 typedef struct BufInfo {
@@ -370,7 +390,42 @@ static void ensure_buf (GeglBufferIterators *i, gint no)
                                         i->i[0].max_size);
 }
 
-gboolean gegl_buffer_iterator_next     (GeglBufferIterator *iterator)
+void
+gegl_buffer_iterator_stop (GeglBufferIterator *iterator)
+{
+  GeglBufferIterators *i = (gpointer)iterator;
+  gint no;
+  for (no=0; no<i->iterators;no++)
+    {
+      gint j;
+      gboolean found = FALSE;
+      for (j=0; j<no; j++)
+        if (i->buffer[no]==i->buffer[j])
+          {
+            found = TRUE;
+            break;
+          }
+      if (!found)
+        gegl_buffer_unlock (i->buffer[no]);
+    }
+
+  for (no=0; no<i->iterators; no++)
+    {
+      if (i->buf[no])
+        iterator_buf_pool_release (i->buf[no]);
+      i->buf[no]=NULL;
+      g_object_unref (i->buffer[no]);
+    }
+#if DEBUG_DIRECT
+  g_print ("%f %f\n", (100.0*direct_read/(in_direct_read+direct_read)),
+                           100.0*direct_write/(in_direct_write+direct_write));
+#endif
+  i->is_finished = TRUE;
+  g_slice_free (GeglBufferIterators, i);
+}
+
+gboolean
+gegl_buffer_iterator_next (GeglBufferIterator *iterator)
 {
   GeglBufferIterators *i = (gpointer)iterator;
   gboolean result = FALSE;
@@ -392,6 +447,9 @@ gboolean gegl_buffer_iterator_next     (GeglBufferIterator *iterator)
               }
           if (!found)
             gegl_buffer_lock (i->buffer[no]);
+
+          if (gegl_cl_is_accelerated ())
+            gegl_buffer_cl_cache_flush (i->buffer[no], &i->rect[no]);
         }
     }
   else
@@ -405,8 +463,7 @@ gboolean gegl_buffer_iterator_next     (GeglBufferIterator *iterator)
               if (i->flags[no] & GEGL_BUFFER_SCAN_COMPATIBLE &&
                   i->flags[no] & GEGL_BUFFER_FORMAT_COMPATIBLE &&
                   i->roi[no].width == i->i[no].buffer->tile_storage->tile_width && (i->flags[no] & GEGL_BUFFER_FORMAT_COMPATIBLE))
-                {
-                   /* direct access */
+                { /* direct access, don't need to do anything */
 #if DEBUG_DIRECT
                    direct_write += i->roi[no].width * i->roi[no].height;
 #endif
@@ -422,7 +479,7 @@ gboolean gegl_buffer_iterator_next     (GeglBufferIterator *iterator)
   /* XXX: should perhaps use _set_unlocked, and keep the lock in the
    * iterator.
    */
-                  gegl_buffer_set (i->buffer[no], &(i->roi[no]), i->format[no], i->buf[no], GEGL_AUTO_ROWSTRIDE);
+                  gegl_buffer_set (i->buffer[no], &(i->roi[no]), 0, i->format[no], i->buf[no], GEGL_AUTO_ROWSTRIDE); /* XXX: use correct level */
                 }
             }
         }
@@ -500,48 +557,24 @@ gboolean gegl_buffer_iterator_next     (GeglBufferIterator *iterator)
   i->iteration_no++;
 
   if (result == FALSE)
-    {
-      for (no=0; no<i->iterators;no++)
-        {
-          gint j;
-          gboolean found = FALSE;
-          for (j=0; j<no; j++)
-            if (i->buffer[no]==i->buffer[j])
-              {
-                found = TRUE;
-                break;
-              }
-          if (!found)
-            gegl_buffer_unlock (i->buffer[no]);
-        }
-
-      for (no=0; no<i->iterators;no++)
-        {
-          if (i->buf[no])
-            iterator_buf_pool_release (i->buf[no]);
-          i->buf[no]=NULL;
-          g_object_unref (i->buffer[no]);
-        }
-#if DEBUG_DIRECT
-      g_print ("%f %f\n", (100.0*direct_read/(in_direct_read+direct_read)),
-                           100.0*direct_write/(in_direct_write+direct_write));
-#endif
-      i->is_finished = TRUE;
-      g_slice_free (GeglBufferIterators, i);
-    }
-
+    gegl_buffer_iterator_stop (iterator);
 
   return result;
 }
 
-GeglBufferIterator *gegl_buffer_iterator_new (GeglBuffer          *buffer,
-                                              const GeglRectangle *roi,
-                                              const Babl          *format,
-                                              guint                flags)
+GeglBufferIterator *
+gegl_buffer_iterator_new (GeglBuffer          *buffer,
+                          const GeglRectangle *roi,
+                          gint                 level,
+                          const Babl          *format,
+                          guint                flags,
+                          GeglAbyssPolicy      abyss_policy)
 {
   GeglBufferIterator *i = (gpointer)g_slice_new0 (GeglBufferIterators);
   /* Because the iterator is nulled above, we can forgo explicitly setting
    * i->is_finished to FALSE. */
-  gegl_buffer_iterator_add (i, buffer, roi, format, flags);
+  i->level = level;
+  gegl_buffer_iterator_add (i, buffer, roi, level, format, flags, abyss_policy);
   return i;
 }
+
