@@ -35,6 +35,7 @@ enum
 static void    gegl_sampler_nearest_get (GeglSampler  *self,
                                          gdouble       x,
                                          gdouble       y,
+                                         GeglMatrix2  *scale,
                                          void         *output);
 static void    set_property             (GObject      *gobject,
                                          guint         prop_id,
@@ -63,10 +64,10 @@ gegl_sampler_nearest_class_init (GeglSamplerNearestClass *klass)
 static void
 gegl_sampler_nearest_init (GeglSamplerNearest *self)
 {
-   GEGL_SAMPLER (self)->context_rect.x = 0;
-   GEGL_SAMPLER (self)->context_rect.y = 0;
-   GEGL_SAMPLER (self)->context_rect.width = 1;
-   GEGL_SAMPLER (self)->context_rect.height = 1;
+   GEGL_SAMPLER (self)->context_rect[0].x = 0;
+   GEGL_SAMPLER (self)->context_rect[0].y = 0;
+   GEGL_SAMPLER (self)->context_rect[0].width = 1;
+   GEGL_SAMPLER (self)->context_rect[0].height = 1;
    GEGL_SAMPLER (self)->interpolate_format = babl_format ("RGBA float");
 }
 
@@ -74,6 +75,7 @@ void
 gegl_sampler_nearest_get (GeglSampler *self,
                           gdouble      x,
                           gdouble      y,
+                          GeglMatrix2 *scale,
                           void        *output)
 {
   gfloat             *sampler_bptr;
