@@ -33,7 +33,6 @@
 #include "gegl-sampler-nearest.h"
 #include "gegl-sampler-linear.h"
 #include "gegl-sampler-cubic.h"
-#include "gegl-sampler-lanczos.h"
 #include "gegl-sampler-lohalo.h"
 
 enum
@@ -116,11 +115,12 @@ gegl_sampler_init (GeglSampler *self)
 }
 
 void
-gegl_sampler_get (GeglSampler *self,
-                  gdouble      x,
-                  gdouble      y,
-                  GeglMatrix2 *scale,
-                  void        *output)
+gegl_sampler_get (GeglSampler   *self,
+                  gdouble        x,
+                  gdouble        y,
+                  GeglMatrix2   *scale,
+                  void          *output,
+                  GeglAbyssPolicy repeat_mode)
 {
   self->get (self, x, y, scale, output);
 }
@@ -277,11 +277,12 @@ gegl_sampler_get_ptr (GeglSampler *const sampler,
         }
 
       gegl_buffer_get (sampler->buffer,
-                       1.0,
                        &fetch_rectangle,
+                       1.0,
                        sampler->interpolate_format,
                        sampler->sampler_buffer[0],
-                       GEGL_AUTO_ROWSTRIDE);
+                       GEGL_AUTO_ROWSTRIDE,
+                       GEGL_ABYSS_NONE);
 
       sampler->sampler_rectangle[0] = fetch_rectangle;
     }
@@ -351,11 +352,12 @@ gegl_sampler_get_from_buffer (GeglSampler *const sampler,
         }
 
       gegl_buffer_get (sampler->buffer,
-                       1.0,
                        &fetch_rectangle,
+                       1.0,
                        sampler->interpolate_format,
                        sampler->sampler_buffer[0],
-                       GEGL_AUTO_ROWSTRIDE);
+                       GEGL_AUTO_ROWSTRIDE,
+                       GEGL_ABYSS_NONE);
 
       sampler->sampler_rectangle[0] = fetch_rectangle;
     }
@@ -446,11 +448,12 @@ gegl_sampler_get_from_mipmap (GeglSampler *const sampler,
         }
 
       gegl_buffer_get (sampler->buffer,
-                       scale,
                        &fetch_rectangle,
+                       scale,
                        sampler->interpolate_format,
                        sampler->sampler_buffer[level],
-                       GEGL_AUTO_ROWSTRIDE);
+                       GEGL_AUTO_ROWSTRIDE,
+                       GEGL_ABYSS_NONE);
 
       sampler->sampler_rectangle[level] = fetch_rectangle;
     }
@@ -478,7 +481,7 @@ get_property (GObject    *object,
         break;
 
       case PROP_FORMAT:
-        g_value_set_pointer (value, self->format);
+        g_value_set_pointer (value, (void*)self->format);
         break;
 
       default:
@@ -557,8 +560,6 @@ gegl_sampler_gtype_from_enum (GeglSamplerType sampler_type)
         return GEGL_TYPE_SAMPLER_LINEAR;
       case GEGL_SAMPLER_CUBIC:
         return GEGL_TYPE_SAMPLER_CUBIC;
-      case GEGL_SAMPLER_LANCZOS:
-        return GEGL_TYPE_SAMPLER_LANCZOS;
       case GEGL_SAMPLER_LOHALO:
         return GEGL_TYPE_SAMPLER_LOHALO;
       default:
@@ -568,7 +569,7 @@ gegl_sampler_gtype_from_enum (GeglSamplerType sampler_type)
 
 GeglSampler *
 gegl_buffer_sampler_new (GeglBuffer       *buffer,
-                         Babl             *format,
+                         const Babl       *format,
                          GeglSamplerType   sampler_type)
 {
   GeglSampler          *sampler;
@@ -576,17 +577,10 @@ gegl_buffer_sampler_new (GeglBuffer       *buffer,
   if (format == NULL)
     format = babl_format ("RaGaBaA float");
   desired_type = gegl_sampler_gtype_from_enum (sampler_type);
-  if (sampler_type == GEGL_SAMPLER_LANCZOS)
-      sampler = g_object_new (desired_type,
-                              "format", format,
-                              "buffer", buffer,
-                              "lanczos_width",  4,
-                              NULL);
-  else
-      sampler = g_object_new (desired_type,
-                              "buffer", buffer,
-                              "format", format,
-                              NULL);
+  sampler = g_object_new (desired_type,
+                          "buffer", buffer,
+                          "format", format,
+                          NULL);
   gegl_sampler_prepare (sampler);
   return sampler;
 }
