@@ -22,6 +22,7 @@
 
 #include <babl/babl.h>
 #include "gegl-buffer-types.h"
+#include "gegl-buffer-private.h"
 #include "gegl-tile-source.h"
 #include "gegl-tile-backend.h"
 
@@ -65,7 +66,7 @@ get_property (GObject    *gobject,
         break;
 
       case PROP_FORMAT:
-        g_value_set_pointer (value, backend->priv->format);
+        g_value_set_pointer (value, (void*)backend->priv->format);
         break;
 
       default:
@@ -177,7 +178,7 @@ gint gegl_tile_backend_get_tile_size (GeglTileBackend *tile_backend)
 }
 
 
-Babl *gegl_tile_backend_get_format (GeglTileBackend *tile_backend)
+const Babl *gegl_tile_backend_get_format (GeglTileBackend *tile_backend)
 {
   return tile_backend->priv->format;
 }
@@ -193,3 +194,8 @@ GeglRectangle gegl_tile_backend_get_extent (GeglTileBackend *tile_backend)
 {
   return tile_backend->priv->extent;
 }
+
+GeglTileSource *gegl_tile_backend_peek_storage (GeglTileBackend *backend)
+{
+  return backend->priv->storage;
+}
