@@ -39,11 +39,7 @@
 
 #include "gegl-utils.h"
 
-static void default_free (gpointer data,
-                          gpointer userdata)
-{
-  gegl_free (data);
-}
+static GStaticMutex cowmutex = G_STATIC_MUTEX_INIT;
 
 GeglTile *gegl_tile_ref (GeglTile *tile)
 {
@@ -51,6 +47,8 @@ GeglTile *gegl_tile_ref (GeglTile *tile)
   return tile;
 }
 
+static int free_data_directly;
+
 void gegl_tile_unref (GeglTile *tile)
 {
   if (!g_atomic_int_dec_and_test (&tile->ref_count))
@@ -68,7 +66,12 @@ void gegl_tile_unref (GeglTile *tile)
       if (tile->next_shared == tile)
         { /* no clones */
           if (tile->destroy_notify)
-            tile->destroy_notify (tile->data, tile->destroy_notify_data);
+            {
+              if (tile->destroy_notify == (void*)&free_data_directly)
+                gegl_free (tile->data);
+              else
+                tile->destroy_notify (tile->destroy_notify_data);
+            }
           tile->data = NULL;
         }
       else
@@ -78,14 +81,17 @@ void gegl_tile_unref (GeglTile *tile)
         }
     }
 
+#ifdef GEGL_USE_TILE_MUTEX
   if (tile->mutex)
     {
       g_mutex_free (tile->mutex);
       tile->mutex = NULL;
     }
+#endif
   g_slice_free (GeglTile, tile);
 }
 
+
 GeglTile *
 gegl_tile_new_bare (void)
 {
@@ -100,8 +106,12 @@ gegl_tile_new_bare (void)
   tile->next_shared = tile;
   tile->prev_shared = tile;
 
+  tile->destroy_notify = (void*)&free_data_directly;
+  tile->destroy_notify_data = NULL;
+
+#ifdef GEGL_USE_TILE_MUTEX
   tile->mutex = g_mutex_new ();
-  tile->destroy_notify = default_free;
+#endif
 
   return tile;
 }
@@ -121,15 +131,29 @@ gegl_tile_dup (GeglTile *src)
   tile->next_shared              = src->next_shared;
   src->next_shared               = tile;
   tile->prev_shared              = src;
+#ifdef GEGL_USE_TILE_MUTEX
   if (tile->next_shared != src)
     {
       g_mutex_lock (tile->next_shared->mutex);
     }
+#endif
+  if (tile->next_shared != src)
+    {
+      g_static_mutex_lock (&cowmutex);
+    }
+
   tile->next_shared->prev_shared = tile;
+
+  if (tile->next_shared != src)
+    {
+      g_static_mutex_unlock (&cowmutex);
+    }
+#ifdef GEGL_USE_TILE_MUTEX
   if (tile->next_shared != src)
     {
       g_mutex_unlock (tile->next_shared->mutex);
     }
+#endif
 
   return tile;
 }
@@ -162,13 +186,15 @@ gegl_tile_unclone (GeglTile *tile)
       /* the tile data is shared with other tiles,
        * create a local copy
        */
+      g_static_mutex_lock (&cowmutex);
       tile->data                     = gegl_memdup (tile->data, tile->size);
-      tile->destroy_notify           = default_free;
+      tile->destroy_notify           = (void*)&free_data_directly;
       tile->destroy_notify_data      = NULL;
       tile->prev_shared->next_shared = tile->next_shared;
       tile->next_shared->prev_shared = tile->prev_shared;
       tile->prev_shared              = tile;
       tile->next_shared              = tile;
+      g_static_mutex_unlock (&cowmutex);
     }
 }
 #if 0
@@ -181,7 +207,9 @@ void gegl_bt (void);
 void
 gegl_tile_lock (GeglTile *tile)
 {
+#ifdef GEGL_USE_TILE_MUTEX
   g_mutex_lock (tile->mutex);
+#endif
 
   if (tile->lock != 0)
     {
@@ -249,7 +277,9 @@ gegl_tile_unlock (GeglTile *tile)
     }
   if (tile->lock==0)
     tile->rev++;
+#ifdef GEGL_USE_TILE_MUTEX
   g_mutex_unlock (tile->mutex);
+#endif
 }
 
 
@@ -302,11 +332,11 @@ void gegl_tile_set_data (GeglTile *tile,
   tile->size = pixel_data_size;
 }
 
-void gegl_tile_set_data_full (GeglTile         *tile,
-                              gpointer          pixel_data,
-                              gint              pixel_data_size,
-                              GeglDestroyNotify destroy_notify,
-                              gpointer          destroy_notify_data)
+void gegl_tile_set_data_full (GeglTile      *tile,
+                              gpointer       pixel_data,
+                              gint           pixel_data_size,
+                              GDestroyNotify destroy_notify,
+                              gpointer       destroy_notify_data)
 {
   tile->data                = pixel_data;
   tile->size                = pixel_data_size;
