@@ -233,7 +233,7 @@ static const GOptionEntry cmd_entries[]=
     {
      "gegl-chunk-size", 0, 0,
      G_OPTION_ARG_STRING, &cmd_gegl_chunk_size,
-     N_("The count of pixels to compute simulantous"), "pixel count"
+     N_("The count of pixels to compute simultaneously"), "pixel count"
     },
     {
      "gegl-quality", 0, 0,
@@ -243,7 +243,7 @@ static const GOptionEntry cmd_entries[]=
     {
      "gegl-threads", 0, 0,
      G_OPTION_ARG_STRING, &cmd_gegl_threads,
-     N_("The number of concurrent processing threads to use."), "<threads>"
+     N_("The number of concurrent processing threads to use"), "<threads>"
     },
     { NULL }
 };
@@ -301,6 +301,12 @@ GeglConfig *gegl_config (void)
               config->threads = GEGL_MAX_THREADS;
             }
         }
+
+      if (g_getenv ("GEGL_USE_OPENCL") != NULL && strcmp(g_getenv ("GEGL_USE_OPENCL"), "yes") == 0)
+        config->use_opencl = TRUE;
+      else
+        config->use_opencl = FALSE;
+
       if (gegl_swap_dir())
         config->swap = g_strdup(gegl_swap_dir ());
     }
@@ -389,7 +395,7 @@ gegl_exit (void)
     }
 
   if (gegl_buffer_leaks ())
-    g_printf ("  buffer-leaks: %i\n", gegl_buffer_leaks ());
+    g_printf ("EEEEeEeek! %i GeglBuffers leaked\n", gegl_buffer_leaks ());
   gegl_tile_cache_destroy ();
 
   if (gegl_swap_dir ())
@@ -587,6 +593,13 @@ gegl_post_parse_hook (GOptionContext *context,
     }
 
   swap_clean ();
+
+  /* Initialize OpenCL if wanted and possible */
+  if (gegl_config()->use_opencl)
+    gegl_cl_init (NULL);
+
+  GEGL_NOTE (GEGL_DEBUG_OPENCL, "Using OpenCL: %d\n", gegl_config()->use_opencl && gegl_cl_is_accelerated ());
+
   return TRUE;
 }
 
