@@ -3,7 +3,7 @@
  * GEGL is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 3 of the License, or (at your option) any later version.
  *
  * GEGL is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -11,9 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
  *
  * Copyright 2006 Øyvind Kolås
  */
@@ -21,11 +19,12 @@
 #ifndef GEGL_XML_H
 #define GEGL_XML_H
 
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 
-gchar    * gegl_to_xml    (GeglNode    *gegl,
-                           const gchar *path_root);
-GeglNode * gegl_parse_xml (const gchar *xmldata,
-                           const gchar *path_root);
+gchar    * gegl_node_to_xml        (GeglNode    *gegl,
+                                    const gchar *path_root);
+GeglNode * gegl_node_new_from_xml  (const gchar *xmldata,
+                                    const gchar *path_root);
+GeglNode * gegl_node_new_from_file (const gchar *path);
 
 #endif
