@@ -35,19 +35,21 @@ static gboolean gegl_operation_point_composer3_process
                                GeglBuffer          *aux,
                                GeglBuffer          *aux2,
                                GeglBuffer          *output,
-                               const GeglRectangle *result);
+                               const GeglRectangle *result,
+                               gint                 level);
 
 static gboolean
 gegl_operation_composer3_process2 (GeglOperation        *operation,
                                    GeglOperationContext *context,
                                    const gchar          *output_prop,
-                                   const GeglRectangle  *result);
+                                   const GeglRectangle  *result,
+                                   gint                  level);
 
 G_DEFINE_TYPE (GeglOperationPointComposer3, gegl_operation_point_composer3, GEGL_TYPE_OPERATION_COMPOSER3)
 
 static void prepare (GeglOperation *operation)
 {
-  Babl *format = babl_format ("RGBA float");
+  const Babl *format = babl_format ("RGBA float");
   gegl_operation_set_format (operation, "input", format);
   gegl_operation_set_format (operation, "aux", format);
   gegl_operation_set_format (operation, "aux2", format);
@@ -80,7 +82,8 @@ static gboolean
 gegl_operation_composer3_process2 (GeglOperation        *operation,
                                    GeglOperationContext *context,
                                    const gchar          *output_prop,
-                                   const GeglRectangle  *result)
+                                   const GeglRectangle  *result,
+                                   gint                  level)
 {
   GeglOperationComposer3Class *klass   = GEGL_OPERATION_COMPOSER3_GET_CLASS (operation);
   GeglBuffer                  *input;
@@ -119,7 +122,7 @@ gegl_operation_composer3_process2 (GeglOperation        *operation,
       success = done;
       if (!done)
         {
-          success = klass->process (operation, input, aux, aux2, output, result);
+          success = klass->process (operation, input, aux, aux2, output, result, context->level);
 
           if (output == GEGL_BUFFER (operation->node->cache))
             gegl_cache_computed (operation->node->cache, result);
@@ -146,7 +149,8 @@ gegl_operation_point_composer3_process (GeglOperation       *operation,
                                         GeglBuffer          *aux,
                                         GeglBuffer          *aux2,
                                         GeglBuffer          *output,
-                                        const GeglRectangle *result)
+                                        const GeglRectangle *result,
+                                        gint                 level)
 {
   GeglOperationPointComposer3Class *point_composer3_class = GEGL_OPERATION_POINT_COMPOSER3_GET_CLASS (operation);
   const Babl *in_format   = gegl_operation_get_format (operation, "input");
@@ -156,26 +160,26 @@ gegl_operation_point_composer3_process (GeglOperation       *operation,
 
   if ((result->width > 0) && (result->height > 0))
     {
-      GeglBufferIterator *i = gegl_buffer_iterator_new (output, result, out_format, GEGL_BUFFER_WRITE);
-      gint read  = gegl_buffer_iterator_add (i, input,  result, in_format, GEGL_BUFFER_READ);
+      GeglBufferIterator *i = gegl_buffer_iterator_new (output, result, level, out_format, GEGL_BUFFER_WRITE, GEGL_ABYSS_NONE);
+      gint read  = gegl_buffer_iterator_add (i, input, result, level, in_format, GEGL_BUFFER_READ, GEGL_ABYSS_NONE);
 
       if (aux)
         {
-          gint foo = gegl_buffer_iterator_add (i, aux,  result, aux_format, GEGL_BUFFER_READ);
+          gint foo = gegl_buffer_iterator_add (i, aux, result, level, aux_format, GEGL_BUFFER_READ, GEGL_ABYSS_NONE);
           if (aux2)
             {
-              gint bar = gegl_buffer_iterator_add (i, aux2,  result, aux2_format, GEGL_BUFFER_READ);
+              gint bar = gegl_buffer_iterator_add (i, aux2, result, level, aux2_format, GEGL_BUFFER_READ, GEGL_ABYSS_NONE);
 
               while (gegl_buffer_iterator_next (i))
                 {
-                   point_composer3_class->process (operation, i->data[read], i->data[foo], i->data[bar], i->data[0], i->length, &(i->roi[0]));
+                   point_composer3_class->process (operation, i->data[read], i->data[foo], i->data[bar], i->data[0], i->length, &(i->roi[0]), level);
                 }
             }
           else
             {
               while (gegl_buffer_iterator_next (i))
                 {
-                   point_composer3_class->process (operation, i->data[read], i->data[foo], NULL, i->data[0], i->length, &(i->roi[0]));
+                   point_composer3_class->process (operation, i->data[read], i->data[foo], NULL, i->data[0], i->length, &(i->roi[0]), level);
                 }
             }
         }
@@ -183,17 +187,17 @@ gegl_operation_point_composer3_process (GeglOperation       *operation,
         {
           if (aux2)
             {
-              gint bar = gegl_buffer_iterator_add (i, aux2,  result, aux2_format, GEGL_BUFFER_READ);
+              gint bar = gegl_buffer_iterator_add (i, aux2, result, level, aux2_format, GEGL_BUFFER_READ, GEGL_ABYSS_NONE);
               while (gegl_buffer_iterator_next (i))
                 {
-                   point_composer3_class->process (operation, i->data[read], NULL, i->data[bar], i->data[0], i->length, &(i->roi[0]));
+                   point_composer3_class->process (operation, i->data[read], NULL, i->data[bar], i->data[0], i->length, &(i->roi[0]), level);
                 }
             }
           else
             {
               while (gegl_buffer_iterator_next (i))
                 {
-                   point_composer3_class->process (operation, i->data[read], NULL, NULL, i->data[0], i->length, &(i->roi[0]));
+                   point_composer3_class->process (operation, i->data[read], NULL, NULL, i->data[0], i->length, &(i->roi[0]), level);
                 }
             }
         }
