@@ -43,7 +43,37 @@ static GeglRectangle get_required_for_output   (GeglOperation       *self,
                                                 const gchar         *input_pad,
                                                 const GeglRectangle *region);
 
-G_DEFINE_TYPE (GeglOperation, gegl_operation, G_TYPE_OBJECT)
+static void gegl_operation_class_init     (GeglOperationClass *klass);
+static void gegl_operation_base_init      (GeglOperationClass *klass);
+static void gegl_operation_init           (GeglOperation      *self);
+
+GType
+gegl_operation_get_type (void)
+{
+  static GType type = 0;
+
+  if (! type)
+    {
+      const GTypeInfo info =
+      {
+        sizeof (GeglOperationClass),
+        (GBaseInitFunc)      gegl_operation_base_init,
+        (GBaseFinalizeFunc) NULL,
+        (GClassInitFunc)     gegl_operation_class_init,
+        NULL,           /* class_finalize */
+        NULL,           /* class_data */
+        sizeof (GeglOperation),
+        0,              /* n_preallocs */
+        (GInstanceInitFunc) gegl_operation_init,
+      };
+
+      type = g_type_register_static (G_TYPE_OBJECT,
+                                     "GeglOperation",
+                                     &info, 0);
+    }
+  return type;
+}
+
 
 static void
 gegl_operation_class_init (GeglOperationClass *klass)
@@ -55,16 +85,22 @@ gegl_operation_class_init (GeglOperationClass *klass)
                                              * name
                                              */
   klass->compat_name               = NULL;
-  klass->description               = NULL;
-  klass->categories                = NULL;
   klass->attach                    = attach;
   klass->prepare                   = NULL;
   klass->no_cache                  = FALSE;
+  klass->opencl_support            = FALSE;
   klass->get_bounding_box          = get_bounding_box;
   klass->get_invalidated_by_change = get_invalidated_by_change;
   klass->get_required_for_output   = get_required_for_output;
 }
 
+static void
+gegl_operation_base_init  (GeglOperationClass *klass)
+{
+  /* XXX: leaked for now, should replace G_DEFINE_TYPE with the expanded one */
+  klass->keys = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+}
+
 static void
 gegl_operation_init (GeglOperation *self)
 {
@@ -100,11 +136,15 @@ gegl_operation_create_pad (GeglOperation *self,
   gegl_node_add_pad (self->node, pad);
 }
 
+void gegl_node_emit_computed (GeglNode *node, const GeglRectangle *rect);
+
+
 gboolean
-gegl_operation_process (GeglOperation       *operation,
-                        GeglOperationContext     *context,
-                        const gchar         *output_pad,
-                        const GeglRectangle *result)
+gegl_operation_process (GeglOperation        *operation,
+                        GeglOperationContext *context,
+                        const gchar          *output_pad,
+                        const GeglRectangle  *result,
+                        gint                  level)
 {
   GeglOperationClass  *klass;
 
@@ -116,11 +156,13 @@ gegl_operation_process (GeglOperation       *operation,
       (result->width == 0 || result->height == 0))
     {
       GeglBuffer *output = gegl_buffer_new (NULL, NULL);
+      g_warning ("%s Eeek: processing 0px rectangle", G_STRLOC);
+      /* when this case is hit.. we've done something bad.. */
       gegl_operation_context_take_object (context, "output", G_OBJECT (output));
       return TRUE;
     }
 
-  return klass->process (operation, context, output_pad, result);
+  return klass->process (operation, context, output_pad, result, level);
 }
 
 /* Calls an extending class' get_bound_box method if defined otherwise
@@ -336,8 +378,8 @@ get_invalidated_by_change (GeglOperation        *self,
 /* returns a freshly allocated list of the properties of the object, does not list
  * the regular gobject properties of GeglNode ('name' and 'operation') */
 GParamSpec **
-gegl_list_properties (const gchar *operation_type,
-                      guint       *n_properties_p)
+gegl_operation_list_properties (const gchar *operation_type,
+                                guint       *n_properties_p)
 {
   GParamSpec  **pspecs;
   GType         type;
@@ -451,3 +493,119 @@ gegl_operation_invalidate (GeglOperation       *operation,
 
   gegl_node_invalidated (node, roi, TRUE);
 }
+
+
+gchar **
+gegl_operation_list_keys (const gchar *operation_name,
+                          guint       *n_keys)
+{
+  GType         type;
+  GObjectClass *klass;
+  GList        *list, *l;
+  gchar       **ret;
+  int count;
+  int i;
+  type = gegl_operation_gtype_from_name (operation_name);
+  if (!type)
+    {
+      if (n_keys)
+        *n_keys = 0;
+      return NULL;
+    }
+  klass  = g_type_class_ref (type);
+  count = g_hash_table_size (GEGL_OPERATION_CLASS (klass)->keys);
+  ret = g_malloc0 (sizeof (gpointer) * (count + 1));
+  list = g_hash_table_get_keys (GEGL_OPERATION_CLASS (klass)->keys);
+  for (i = 0, l = list; l; l = l->next)
+    {
+      ret[i] = l->data;
+    }
+  g_list_free (list);
+  if (n_keys)
+    *n_keys = count;
+  g_type_class_unref (klass);
+  return ret;
+}
+
+void
+gegl_operation_class_set_key (GeglOperationClass *klass,
+                              const gchar        *key_name,
+                              const gchar        *key_value)
+{
+  if (!key_value)
+    {
+      g_hash_table_remove (klass->keys, key_name);
+      return;
+    }
+  else
+    {
+      key_value = g_strdup (key_value);
+      g_hash_table_insert (klass->keys, g_strdup (key_name),
+                           (void*)key_value);
+    }
+  if (!strcmp (key_name, "name"))
+    {
+      klass->name = key_value;
+    }
+}
+
+void
+gegl_operation_class_set_keys (GeglOperationClass *klass,
+                               const gchar        *key_name,
+                                ...)
+{
+  va_list var_args;
+
+  va_start (var_args, key_name);
+  while (key_name)
+    {
+      const char *value = va_arg (var_args, char *);
+
+      gegl_operation_class_set_key (klass, key_name, value);
+
+      key_name = va_arg (var_args, char *);
+    }
+  va_end (var_args);
+}
+
+void
+gegl_operation_set_key (const gchar *operation_name,
+                        const gchar *key_name,
+                        const gchar *key_value)
+{
+  GType         type;
+  GObjectClass *klass;
+  type = gegl_operation_gtype_from_name (operation_name);
+  if (!type)
+    return;
+  klass  = g_type_class_ref (type);
+  gegl_operation_class_set_key (GEGL_OPERATION_CLASS (klass), key_name, key_value);
+  g_type_class_unref (klass);
+}
+
+const gchar *
+gegl_operation_class_get_key (GeglOperationClass *operation_class,
+                              const gchar        *key_name)
+{
+  const gchar  *ret = NULL;
+  ret = g_hash_table_lookup (GEGL_OPERATION_CLASS (operation_class)->keys, key_name);
+  return ret;
+}
+
+const gchar *
+gegl_operation_get_key (const gchar *operation_name,
+                        const gchar *key_name)
+{
+  GType         type;
+  GObjectClass *klass;
+  const gchar  *ret = NULL;
+  type = gegl_operation_gtype_from_name (operation_name);
+  if (!type)
+    {
+      return NULL;
+    }
+  klass  = g_type_class_ref (type);
+  ret = gegl_operation_class_get_key (GEGL_OPERATION_CLASS (klass), key_name);
+  g_type_class_unref (klass);
+  return ret;
+}
