@@ -80,15 +80,19 @@ gegl_prepare_visitor_visit_node (GeglVisitor *self,
         g_assert (graph);
         if (GEGL_NODE (graph)->operation)
           {
+            g_mutex_lock (GEGL_NODE (graph)->mutex);
             /* issuing a prepare on the graph, FIXME: we might need to do
              * a cycle of prepares as deep as the nesting of graphs,.
              * (or find a better way to do this) */
             gegl_operation_prepare (GEGL_NODE (graph)->operation);
+            g_mutex_unlock (GEGL_NODE (graph)->mutex);
           }
       }
   }
 
+  g_mutex_lock (node->mutex);
   gegl_operation_prepare (operation);
+  g_mutex_unlock (node->mutex);
   {
     /* initialise the "needed rectangle" to an empty one */
     GeglRectangle empty ={0,};
