@@ -955,8 +955,9 @@ gegl_expcombine_get_exposures (GeglOperation        *operation,
       e->pixels[PIXELS_FULL]   = g_new (gfloat, full_roi->width  *
                                                 full_roi->height *
                                                 components);
-      gegl_buffer_get (buffer, 1.0, full_roi, babl_format (PAD_FORMAT),
-                       e->pixels[PIXELS_FULL], GEGL_AUTO_ROWSTRIDE);
+      gegl_buffer_get (buffer, full_roi, 1.0, babl_format (PAD_FORMAT),
+                       e->pixels[PIXELS_FULL], GEGL_AUTO_ROWSTRIDE,
+                       GEGL_ABYSS_NONE);
 
       g_return_val_if_fail (scale <= 1.0f, NULL);
       if (scale == 1.0f)
@@ -967,8 +968,9 @@ gegl_expcombine_get_exposures (GeglOperation        *operation,
                                             (scaled_roi->width  *
                                              scaled_roi->height *
                                              components));
-          gegl_buffer_get (buffer, scale, scaled_roi, babl_format (PAD_FORMAT),
-                           e->pixels[PIXELS_SCALED], GEGL_AUTO_ROWSTRIDE);
+          gegl_buffer_get (buffer, scaled_roi, scale, babl_format (PAD_FORMAT),
+                           e->pixels[PIXELS_SCALED], GEGL_AUTO_ROWSTRIDE,
+                           GEGL_ABYSS_NONE);
         }
 
       e->pixels[PIXELS_ACTIVE] = e->pixels[PIXELS_FULL];
@@ -1058,7 +1060,8 @@ static gboolean
 gegl_expcombine_process (GeglOperation        *operation,
                          GeglOperationContext *context,
                          const gchar          *output_pad,
-                         const GeglRectangle  *full_roi)
+                         const GeglRectangle  *full_roi,
+                         gint                  level)
 {
   GeglChantO *o           = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer *output      = gegl_operation_context_get_target (context,
@@ -1199,7 +1202,7 @@ gegl_expcombine_process (GeglOperation        *operation,
 #endif
 
   /* Save the HDR components to the output buffer. */
-  gegl_buffer_set (output, full_roi, babl_format (PAD_FORMAT), hdr,
+  gegl_buffer_set (output, full_roi, 0, babl_format (PAD_FORMAT), hdr,
                    GEGL_AUTO_ROWSTRIDE);
   gegl_cache_computed (gegl_node_get_cache (operation->node), full_roi);
 
@@ -1280,13 +1283,15 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_bounding_box  = gegl_expcombine_get_bounding_box;
   operation_class->get_cached_region = gegl_expcombine_get_cached_region;
 
+  operation_class->prepare     = gegl_expcombine_prepare;
   operation_class->get_required_for_output = gegl_expcombine_get_required_for_output;
 
-  operation_class->name        = "gegl:exp-combine";
-  operation_class->categories  = "compositors";
-  operation_class->description =
-      _("Combine multiple scene exposures into one high range buffer");
-  operation_class->prepare     = gegl_expcombine_prepare;
+  gegl_operation_class_set_keys (operation_class,
+  "name"       , "gegl:exp-combine",
+  "categories" , "compositors",
+  "description",
+      _("Combine multiple scene exposures into one high range buffer"),
+      NULL);
 }
 
 
