@@ -22,11 +22,16 @@
 
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_double (alpha, _("Alpha"),    -G_MAXDOUBLE, G_MAXDOUBLE, 1.2, _(""))
-gegl_chant_double (scale, _("Scale"),    -G_MAXDOUBLE, G_MAXDOUBLE, 1.8, _(""))
-gegl_chant_double (zoff,  _("Z offset"), -G_MAXDOUBLE, G_MAXDOUBLE,  -1, _(""))
-gegl_chant_double (seed,  _("Seed"),     -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, _(""))
-gegl_chant_int    (n,     _("Iteration"), 0, 20, 3, _(""))
+gegl_chant_double_ui (alpha, _("Alpha"),    -G_MAXDOUBLE, G_MAXDOUBLE, 1.2, 0.0, 4.0, 1.0,
+                      NULL)
+gegl_chant_double_ui (scale, _("Scale"),    -G_MAXDOUBLE, G_MAXDOUBLE, 1.8, 0.0, 20.0, 1.0,
+                      NULL)
+gegl_chant_double_ui (zoff,  _("Z offset"), -G_MAXDOUBLE, G_MAXDOUBLE,  -1, -1.0, 8.0, 1.0,
+                      NULL)
+gegl_chant_double_ui (seed,  _("Seed"),     -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, 0.0, 100.0, 1.0,
+                      NULL)
+gegl_chant_int       (n,     _("Iteration"), 0, 20, 3,
+                      NULL)
 
 #else
 
@@ -54,7 +59,8 @@ static gboolean
 process (GeglOperation       *operation,
          void                *out_buf,
          glong                n_pixels,
-         const GeglRectangle *roi)
+         const GeglRectangle *roi,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
   gfloat     *out_pixel = out_buf;
@@ -96,13 +102,15 @@ gegl_chant_class_init (GeglChantClass *klass)
   point_render_class->process = process;
   operation_class->get_bounding_box = get_bounding_box;
   operation_class->prepare = prepare;
-
-  operation_class->name        = "perlin-noise";
-  operation_class->categories  = "render";
-  operation_class->description = _("Perlin noise generator.");
-
   operation_class->no_cache = TRUE;
   operation_class->get_cached_region = NULL;
+
+  gegl_operation_class_set_keys (operation_class,
+    "name"       , "gegl:perlin-noise",
+    "categories" , "render",
+    "description", _("Perlin noise generator"),
+    NULL);
+
 }
 
 #endif
