@@ -33,7 +33,7 @@
 
 static void prepare (GeglOperation *operation)
 {
-  Babl *format = babl_format ("RaGaBaA float");
+  const Babl *format = babl_format ("RaGaBaA float");
 
   gegl_operation_set_format (operation, "input", format);
   gegl_operation_set_format (operation, "aux", format);
@@ -41,14 +41,14 @@ static void prepare (GeglOperation *operation)
 }
 
 static gboolean
-process (GeglOperation        *op,
-          void                *in_buf,
-          void                *aux_buf,
-          void                *out_buf,
-          glong                n_pixels,
-          const GeglRectangle *roi)
+process (GeglOperation       *op,
+         void                *in_buf,
+         void                *aux_buf,
+         void                *out_buf,
+         glong                n_pixels,
+         const GeglRectangle *roi,
+         gint                 level)
 {
-  gint i;
   gfloat * GEGL_ALIGNED in = in_buf;
   gfloat * GEGL_ALIGNED aux = aux_buf;
   gfloat * GEGL_ALIGNED out = out_buf;
@@ -56,7 +56,7 @@ process (GeglOperation        *op,
   if (aux==NULL)
     return TRUE;
 
-  for (i = 0; i < n_pixels; i++)
+  while (n_pixels--)
     {
       out[0] = aux[0] + in[0] * (1.0f - aux[3]);
       out[1] = aux[1] + in[1] * (1.0f - aux[3]);
@@ -70,11 +70,70 @@ process (GeglOperation        *op,
   return TRUE;
 }
 
+#include "opencl/gegl-cl.h"
+
+static const char* kernel_source =
+"__kernel void kernel_over(__global const float4     *in,       \n"
+"                          __global const float4     *aux,      \n"
+"                          __global       float4     *out)      \n"
+"{                                                              \n"
+"  int gid = get_global_id(0);                                  \n"
+"  float4 in_v  = in [gid];                                     \n"
+"  float4 aux_v = aux[gid];                                     \n"
+"  float4 out_v;                                                \n"
+"  out_v.xyz = aux_v.xyz + in_v.xyz * (1.0f - aux_v.w);         \n"
+"  out_v.w   = aux_v.w + in_v.w - aux_v.w * in_v.w;             \n"
+"  out[gid]  = out_v;                                           \n"
+"}                                                              \n";
+
+static gegl_cl_run_data *cl_data = NULL;
+
+static cl_int
+cl_process (GeglOperation       *op,
+            cl_mem               in_tex,
+            cl_mem               aux_tex,
+            cl_mem               out_tex,
+            size_t               global_worksize,
+            const GeglRectangle *roi,
+            gint                 level)
+{
+  /* Retrieve a pointer to GeglChantO structure which contains all the
+   * chanted properties
+   */
+
+  cl_int cl_err = 0;
+
+  if (aux_tex == NULL)
+    return 0;
+
+  if (!cl_data)
+    {
+      const char *kernel_name[] = {"kernel_over", NULL};
+      cl_data = gegl_cl_compile_and_build (kernel_source, kernel_name);
+    }
+
+  if (!cl_data) return 1;
+
+  cl_err |= gegl_clSetKernelArg(cl_data->kernel[0], 0, sizeof(cl_mem),   (void*)&in_tex);
+  cl_err |= gegl_clSetKernelArg(cl_data->kernel[0], 1, sizeof(cl_mem),   (void*)&aux_tex);
+  cl_err |= gegl_clSetKernelArg(cl_data->kernel[0], 2, sizeof(cl_mem),   (void*)&out_tex);
+  if (cl_err != CL_SUCCESS) return cl_err;
+
+  cl_err = gegl_clEnqueueNDRangeKernel(gegl_cl_get_command_queue (),
+                                        cl_data->kernel[0], 1,
+                                        NULL, &global_worksize, NULL,
+                                        0, NULL, NULL);
+  if (cl_err != CL_SUCCESS) return cl_err;
+
+  return cl_err;
+}
+
 /* Fast paths */
 static gboolean operation_process (GeglOperation        *operation,
                                    GeglOperationContext *context,
                                    const gchar          *output_prop,
-                                   const GeglRectangle  *result)
+                                   const GeglRectangle  *result,
+                                   gint                  level)
 {
   GeglOperationClass  *operation_class;
   gpointer input, aux;
@@ -113,7 +172,7 @@ static gboolean operation_process (GeglOperation        *operation,
   /* chain up, which will create the needed buffers for our actual
    * process function
    */
-  return operation_class->process (operation, context, output_prop, result);
+  return operation_class->process (operation, context, output_prop, result, level);
 }
 
 static void
@@ -128,12 +187,18 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->process = operation_process;
 
   point_composer_class->process = process;
+  point_composer_class->cl_process = cl_process;
+
+  operation_class->opencl_support = TRUE;
 
   operation_class->compat_name = "gegl:over";
-  operation_class->name        = "svg:src-over";
-  operation_class->description =
-        _("Porter Duff operation over (d = cA + cB * (1 - aA))");
-  operation_class->categories  = "compositors:porter-duff";
+
+  gegl_operation_class_set_keys (operation_class,
+    "name"       , "svg:src-over",
+    "categories" , "compositors:porter-duff",
+    "description",
+          _("Porter Duff operation over (d = cA + cB * (1 - aA))"),
+    NULL);
 }
 
 #endif
