@@ -33,7 +33,7 @@
 
 static void prepare (GeglOperation *operation)
 {
-  Babl *format = babl_format ("RGBA float");
+  const Babl *format = babl_format ("RGBA float");
 
   gegl_operation_set_format (operation, "input",  format);
   gegl_operation_set_format (operation, "aux",    format);
@@ -48,7 +48,8 @@ process (GeglOperation        *op,
           void                *max_buf,
           void                *out_buf,
           glong                n_pixels,
-          const GeglRectangle *roi)
+          const GeglRectangle *roi,
+          gint                 level)
 {
   gint i;
   gfloat *in = in_buf;
@@ -89,10 +90,12 @@ gegl_chant_class_init (GeglChantClass *klass)
 
   point_composer3_class->process = process;
 
-  operation_class->name        = "gegl:remap";
-  operation_class->description =
-        _("stretch components of pixels individually based on luminance envelopes");
-  operation_class->categories  = "compositors:porter-duff";
+  gegl_operation_class_set_keys (operation_class,
+    "name"       , "gegl:remap",
+    "description",
+          _("stretch components of pixels individually based on luminance envelopes"),
+    "categories" , "compositors:porter-duff",
+    NULL);
 }
 
 #endif
