@@ -33,7 +33,8 @@ static gboolean
 inner_process (gdouble  min,
                gdouble  max,
                gfloat  *buf,
-               gint     n_pixels)
+               gint     n_pixels,
+               gint     level)
 {
   gint o;
 
@@ -60,7 +61,7 @@ buffer_get_min_max (GeglBuffer *buffer,
 
   gfloat *buf = g_new0 (gfloat, 4 * gegl_buffer_get_pixel_count (buffer));
   gint i;
-  gegl_buffer_get (buffer, 1.0, NULL, babl_format ("RGBA float"), buf, GEGL_AUTO_ROWSTRIDE);
+  gegl_buffer_get (buffer, NULL, 1.0, babl_format ("RGBA float"), buf, GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
   for (i=0;i< gegl_buffer_get_pixel_count (buffer);i++)
     {
       gint component;
@@ -100,7 +101,8 @@ static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *input,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   gdouble  min, max;
 
@@ -116,14 +118,16 @@ process (GeglOperation       *operation,
     for (row = 0; row < result->height; row = consumed)
       {
         gint chunk = consumed+chunk_size<result->height?chunk_size:result->height-consumed;
-        GeglRectangle line = { result->x,
-                               result->y + row,
-                               result->width,
-                               chunk};
+        GeglRectangle line;
 
-        gegl_buffer_get (input, 1.0, &line, babl_format ("RGBA float"), buf, GEGL_AUTO_ROWSTRIDE);
-        inner_process (min, max, buf, result->width  * chunk);
-        gegl_buffer_set (output, &line, babl_format ("RGBA float"), buf,
+        line.x = result->x;
+        line.y = result->y + row;
+        line.width = result->width;
+        line.height = chunk;
+
+        gegl_buffer_get (input, &line, 1.0, babl_format ("RGBA float"), buf, GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
+        inner_process (min, max, buf, result->width  * chunk, level);
+        gegl_buffer_set (output, &line, 0, babl_format ("RGBA float"), buf,
                          GEGL_AUTO_ROWSTRIDE);
         consumed+=chunk;
       }
@@ -151,12 +155,14 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->prepare = prepare;
   operation_class->get_required_for_output = get_required_for_output;
 
-  operation_class->name        = "stretch-contrast";
-  operation_class->categories  = "color:enhance";
-  operation_class->description =
+  gegl_operation_class_set_keys (operation_class,
+    "name"       , "gegl:stretch-contrast",
+    "categories" , "color:enhance",
+    "description",
         _("Scales the components of the buffer to be in the 0.0-1.0 range. "
           "This improves images that make poor use of the available contrast "
-          "(little contrast, very dark, or very bright images).");
+          "(little contrast, very dark, or very bright images)."),
+        NULL);
 }
 
 #endif
