@@ -37,7 +37,7 @@ gegl_chant_string (values, _("Values"), "", _("list of <number>s"))
 
 static void prepare (GeglOperation *operation)
 {
-  Babl *format = babl_format ("RaGaBaA float");
+  const Babl *format = babl_format ("RaGaBaA float");
 
   gegl_operation_set_format (operation, "input", format);
   gegl_operation_set_format (operation, "output", format);
@@ -48,7 +48,8 @@ process (GeglOperation       *op,
          void                *in_buf,
          void                *out_buf,
          glong                n_pixels,
-         const GeglRectangle *roi)
+         const GeglRectangle *roi,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (op);
   gfloat     *in = in_buf;
@@ -125,9 +126,11 @@ gegl_chant_class_init (GeglChantClass *klass)
   point_filter_class->process = process;
   operation_class->prepare = prepare;
 
-  operation_class->name        = "svg-matrix";
-  operation_class->categories  = "compositors:svgfilter";
-  operation_class->description = _("SVG color matrix operation svg_matrix");
+  gegl_operation_class_set_keys (operation_class,
+    "name"       , "gegl:svg-matrix",
+    "categories" , "compositors:svgfilter",
+    "description", _("SVG color matrix operation svg_matrix"),
+    NULL);
 }
 
 #endif
