@@ -21,9 +21,10 @@
 
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_double(std_dev, _("Std. Dev."), 0.0, 100.0, 1.0,
+gegl_chant_double_ui (std_dev, _("Std. Dev."), 0.0, 500.0, 1.0, 0.0, 200.0, 1.5,
                   _("Standard deviation (spatial scale factor)"))
-gegl_chant_double(scale,  _("Scale"), 0.0, 100.0, 1.0, _("Scale, strength of effect."))
+gegl_chant_double_ui (scale,  _("Scale"), 0.0, 100.0, 1.0, 0.0, 100.0, 1.5,
+                  _("Scale, strength of effect"))
 
 #else
 
@@ -65,11 +66,13 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class = GEGL_OPERATION_CLASS (klass);
   operation_class->attach = attach;
 
-  operation_class->name        = "gegl:unsharp-mask";
-  operation_class->categories  = "meta:enhance";
-  operation_class->description =
+  gegl_operation_class_set_keys (operation_class,
+  "name"       , "gegl:unsharp-mask",
+  "categories" , "meta:enhance",
+  "description",
         _("Performs an unsharp mask on the input buffer (sharpens an image by "
-          "adding false mach-bands around edges).");
+          "adding false mach-bands around edges)"),
+        NULL);
 }
 
 #endif
