@@ -34,6 +34,7 @@ gegl_chant_double (height, _("Height"), -G_MAXFLOAT, G_MAXFLOAT, 10.0, _("Height
 
 #include "gegl-chant.h"
 #include "graph/gegl-node.h"
+#include "buffer/gegl-buffer-cl-cache.h"
 #include <math.h>
 
 static GeglNode *
@@ -112,7 +113,8 @@ static gboolean
 gegl_crop_process (GeglOperation        *operation,
                    GeglOperationContext *context,
                    const gchar          *output_prop,
-                   const GeglRectangle  *result)
+                   const GeglRectangle  *result,
+                   gint                  level)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *input;
@@ -171,9 +173,11 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_invalidated_by_change = gegl_crop_get_invalidated_by_change;
   operation_class->get_required_for_output   = gegl_crop_get_required_for_output;
 
-  operation_class->name        = "gegl:crop";
-  operation_class->categories  = "core";
-  operation_class->description = _("Crop a buffer");
+  gegl_operation_class_set_keys (operation_class,
+      "name",        "gegl:crop",
+      "categories",  "core",
+      "description", _("Crop a buffer"),
+      NULL);
 
   operation_class->no_cache = TRUE;
 }
