@@ -22,8 +22,8 @@
 
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_file_path (path, _("File"), "/home/pippin/input.avi", _("Path of file to load."))
-gegl_chant_int (frame, _("Frame"), 0, 1000000, 0, _("frame number"))
+gegl_chant_file_path (path, _("File"), "/home/pippin/input.avi", _("Path of file to load"))
+gegl_chant_int (frame, _("Frame"), 0, 1000000, 0, _("Frame number"))
 
 #else
 
@@ -364,7 +364,8 @@ get_bounding_box (GeglOperation *operation)
 static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
   Priv       *p = (Priv*)o->chant_data;
@@ -414,7 +415,7 @@ process (GeglOperation       *operation,
                 }
               }
           }
-        gegl_buffer_set (output, NULL, NULL, buf, GEGL_AUTO_ROWSTRIDE);
+        gegl_buffer_set (output, NULL, 0, NULL, buf, GEGL_AUTO_ROWSTRIDE);
         g_free (buf);
       }
   }
@@ -464,9 +465,11 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_cached_region = get_cached_region;
   operation_class->prepare = prepare;
 
-  operation_class->name        = "gegl:ff-load";
-  operation_class->categories  = "input:video";
-  operation_class->description = _("FFmpeg video frame importer.");
+  gegl_operation_class_set_keys (operation_class,
+    "name"        , "gegl:ff-load",
+    "categories"  , "input:video",
+    "description" , _("FFmpeg video frame importer"),
+    NULL);
 }
 
 #endif
