@@ -25,27 +25,27 @@
 
 
 gegl_chant_color  (fill, _("Fill Color"),  "rgba(0.0,0.0,0.0,0.6)",
-                         _("Color of paint to use for filling, use 0 opacity to disable filling."))
+                         _("Color of paint to use for filling, use 0 opacity to disable filling"))
 gegl_chant_color  (stroke,    _("Stroke Color"),      "rgba(0.0,0.0,0.0,0.0)",
-                             _("Color of paint to use for stroking."))
+                             _("Color of paint to use for stroking"))
 
 gegl_chant_double (stroke_width,_("Stroke width"),  0.0, 200.0, 2.0,
-                             _("The width of the brush used to stroke the path."))
+                             _("The width of the brush used to stroke the path"))
 
 gegl_chant_double (stroke_opacity,  _("Stroke opacity"),  -2.0, 2.0, 1.0,
-                             _("Opacity of stroke, note, does not behave like SVG since at the moment stroking is done using an airbrush tool."))
+                             _("Opacity of stroke, note, does not behave like SVG since at the moment stroking is done using an airbrush tool"))
 
 gegl_chant_double (stroke_hardness, _("Hardness"),   0.0, 1.0, 0.6,
-                             _("hardness of brush, 0.0 for soft brush 1.0 for hard brush."))
+                             _("Hardness of the brush, 0.0 for a soft brush, 1.0 for a hard brush"))
 
-gegl_chant_string (fill_rule,_("Fill rule."), "nonzero",
-                             _("how to determine what to fill (nonzero|evenodd"))
+gegl_chant_string (fill_rule,_("Fill rule"), "nonzero",
+                             _("How to determine what to fill (nonzero|evenodd"))
 
 gegl_chant_string (transform,_("Transform"), "",
-                             _("svg style description of transform."))
+                             _("SVG style description of transform"))
 
 gegl_chant_double (fill_opacity, _("Fill opacity"),  -2.0, 2.0, 1.0,
-                             _("The fill opacity to use."))
+                             _("The fill opacity to use"))
 
 gegl_chant_path   (d,        _("Vector"),
                              _("A GeglVector representing the path of the stroke"))
@@ -67,10 +67,10 @@ static void path_changed (GeglPath *path,
 #include <math.h>
 
 typedef struct StampStatic {
-  gboolean  valid;
-  Babl     *format;
-  gfloat   *buf;
-  gdouble   radius;
+  gboolean    valid;
+  const Babl *format;
+  gfloat     *buf;
+  gdouble     radius;
 }StampStatic;
 
 static void gegl_path_stroke  (GeglBuffer *buffer,
@@ -232,7 +232,7 @@ gegl_path_stamp (GeglBuffer *buffer,
   roi.width = ceil (x+radius) - floor (x-radius);
   roi.height = ceil (y+radius) - floor (y-radius);
 
-  gegl_color_get_rgba4f (color, col);
+  gegl_color_get_pixel (color, babl_format ("RGBA float"), col);
 
   /* bail out if we wouldn't leave a mark on the buffer */
   if (!gegl_rectangle_intersect (&temp, &roi, clip_rect))
@@ -358,7 +358,8 @@ static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *input,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
 
@@ -511,9 +512,11 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->detect = detect;
   /*operation_class->no_cache = TRUE;*/
 
-  operation_class->name        = "gegl:path";
-  operation_class->categories  = "render";
-  operation_class->description = _("Renders a brush stroke");
+  gegl_operation_class_set_keys (operation_class,
+    "name"        , "gegl:path",
+    "categories"  , "render",
+    "description" , _("Renders a brush stroke"),
+    NULL);
 }
 
 
