@@ -61,7 +61,8 @@ static void prepare (GeglOperation *operation)
 static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
 
@@ -74,7 +75,7 @@ process (GeglOperation       *operation,
       extent.width = gdk_pixbuf_get_width (o->pixbuf);
       extent.height = gdk_pixbuf_get_height (o->pixbuf);
 
-      gegl_buffer_set (output, &extent, NULL, gdk_pixbuf_get_pixels (o->pixbuf),
+      gegl_buffer_set (output, &extent, 0, NULL, gdk_pixbuf_get_pixels (o->pixbuf),
                        GEGL_AUTO_ROWSTRIDE);
     }
   return TRUE;
@@ -95,10 +96,12 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->prepare = prepare;
   /*operation_class->no_cache = TRUE;*/
 
-  operation_class->name        = "gegl:pixbuf";
-  operation_class->categories  = "programming:input";
-  operation_class->description =
-        _("Uses the GdkPixbuf located at the memory location in <em>pixbuf</em>.");
+  gegl_operation_class_set_keys (operation_class,
+    "name"        , "gegl:pixbuf",
+    "categories"  , "programming:input",
+    "description" ,
+          _("Uses the GdkPixbuf located at the memory location in <em>pixbuf</em>."),
+          NULL);
 }
 
 #endif
