@@ -70,7 +70,7 @@ gegl_buffer_export_png (GeglBuffer  *gegl_buffer,
   png_color_16   white;
   int            png_color_type;
   gchar          format_string[16];
-  Babl          *format;
+  const Babl    *format;
   gint           bit_depth = 8;
 
   if (!strcmp (path, "-"))
@@ -183,7 +183,7 @@ gegl_buffer_export_png (GeglBuffer  *gegl_buffer,
       rect.width = width;
       rect.height = 1;
 
-      gegl_buffer_get (gegl_buffer, 1.0, &rect, format, pixels, GEGL_AUTO_ROWSTRIDE);
+      gegl_buffer_get (gegl_buffer, &rect, 1.0, babl_format (format_string), pixels, GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
 
       png_write_rows (png, &pixels, 1);
     }
@@ -202,7 +202,8 @@ gegl_buffer_export_png (GeglBuffer  *gegl_buffer,
 static gboolean
 gegl_png_save_process (GeglOperation       *operation,
                        GeglBuffer          *input,
-                       const GeglRectangle *result)
+                       const GeglRectangle *result,
+                       gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
 
@@ -225,10 +226,12 @@ gegl_chant_class_init (GeglChantClass *klass)
   sink_class->process    = gegl_png_save_process;
   sink_class->needs_full = TRUE;
 
-  operation_class->name        = "gegl:png-save";
-  operation_class->categories  = "output";
-  operation_class->description =
-        _("PNG image saver (passes the buffer through, saves as a side-effect.)");
+  gegl_operation_class_set_keys (operation_class,
+  "name"       , "gegl:png-save",
+  "categories" , "output",
+  "description",
+        _("PNG image saver (passes the buffer through, saves as a side-effect.)"),
+        NULL);
 
   gegl_extension_handler_register_saver (".png", "gegl:png-save");
 }
