@@ -203,7 +203,8 @@ static gboolean update (gpointer operation)
 static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
   Priv       *p = (Priv*)o->chant_data;
@@ -283,11 +284,11 @@ process (GeglOperation       *operation,
                 }
             }
         }
-      gegl_buffer_set (output, NULL, NULL, foobuf, GEGL_AUTO_ROWSTRIDE);
+      gegl_buffer_set (output, NULL, 0, NULL, foobuf, GEGL_AUTO_ROWSTRIDE);
     }
   else
     {
-      gegl_buffer_set (output, NULL, NULL, capbuf, GEGL_AUTO_ROWSTRIDE);
+      gegl_buffer_set (output, NULL, 0, NULL, capbuf, GEGL_AUTO_ROWSTRIDE);
     }
   return  TRUE;
 }
@@ -315,10 +316,11 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_cached_region = get_cached_region;
   operation_class->prepare          = prepare;
 
-  operation_class->name        = "gegl:v4l";
-  operation_class->categories  = "input:video";
-  operation_class->description =
-    _("Video4Linux input, webcams framegrabbers and similar devices.");
+  gegl_operation_class_set_keys (operation_class,
+    "name"        , "gegl:v4l",
+    "categories"  , "input:video",
+    "description" , _("Video4Linux input, webcams framegrabbers and similar devices."),
+    NULL);
 }
 
 
