@@ -27,7 +27,7 @@
 gegl_chant_double (radius, _("Radius"), 0.0, 70.0, 4.0,
   _("Radius of square pixel region (width and height will be radius*2+1)"))
 gegl_chant_double (percentile, _("Percentile"), 0.0, 100.0, 50,
-  _("The percentile to compute, defaults to 50, which is a median filter."))
+  _("The percentile to compute, defaults to 50, which is a median filter"))
 
 #else
 
@@ -59,7 +59,8 @@ static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *input,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
@@ -172,7 +173,8 @@ median (GeglBuffer *src,
   src_buf = g_malloc0 (gegl_buffer_get_pixel_count (src) * 4 * 4);
   dst_buf = g_malloc0 (gegl_buffer_get_pixel_count (dst) * 4 * 4);
 
-  gegl_buffer_get (src, 1.0, NULL, babl_format ("RGBA float"), src_buf, GEGL_AUTO_ROWSTRIDE);
+  gegl_buffer_get (src, NULL, 1.0, babl_format ("RGBA float"), src_buf, GEGL_AUTO_ROWSTRIDE,
+                   GEGL_ABYSS_NONE);
 
   offset = 0;
   for (y=0; y<gegl_buffer_get_height (dst); y++)
@@ -202,7 +204,7 @@ median (GeglBuffer *src,
           dst_buf[offset*4+u] = median_pix[u];
         offset++;
       }
-  gegl_buffer_set (dst, NULL, babl_format ("RGBA float"), dst_buf,
+  gegl_buffer_set (dst, NULL, 0, babl_format ("RGBA float"), dst_buf,
                    GEGL_AUTO_ROWSTRIDE);
   g_free (src_buf);
   g_free (dst_buf);
@@ -221,11 +223,13 @@ gegl_chant_class_init (GeglChantClass *klass)
   filter_class->process = process;
   operation_class->prepare = prepare;
 
-  operation_class->name        = "gegl:box-percentile";
-  operation_class->categories  = "misc";
-  operation_class->description =
+  gegl_operation_class_set_keys (operation_class,
+    "name"       , "gegl:box-percentile",
+    "categories" , "misc",
+    "description",
         _("Sets the target pixel to the color corresponding to a given percentile "
-          "when colors are sorted by luminance.");
+          "when colors are sorted by luminance"),
+        NULL);
 }
 
 #endif
