@@ -47,7 +47,8 @@ demosaic (GeglChantO          *op,
   src_buf = g_new0 (gfloat, src_rect->width * src_rect->height * 1);
   dst_buf = g_new0 (gfloat, dst_rect->width * dst_rect->height * 3);
 
-  gegl_buffer_get (src, 1.0, src_rect, babl_format ("Y float"), src_buf, GEGL_AUTO_ROWSTRIDE);
+  gegl_buffer_get (src, src_rect, 1.0, babl_format ("Y float"), src_buf,
+                   GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
 
   offset=0;
   for (y=src_rect->y; y < dst_rect->height + src_rect->y; y++)
@@ -103,7 +104,7 @@ demosaic (GeglChantO          *op,
         }
     }
 
-  gegl_buffer_set (dst, dst_rect, babl_format ("RGB float"), dst_buf, GEGL_AUTO_ROWSTRIDE);
+  gegl_buffer_set (dst, dst_rect, 0, babl_format ("RGB float"), dst_buf, GEGL_AUTO_ROWSTRIDE);
   g_free (src_buf);
   g_free (dst_buf);
 }
@@ -120,7 +121,8 @@ static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *input,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle compute = gegl_operation_get_required_for_output (operation, "input", result);
@@ -143,9 +145,11 @@ gegl_chant_class_init (GeglChantClass *klass)
   filter_class->process = process;
   operation_class->prepare = prepare;
 
-  operation_class->name        = "gegl:demosaic-simple";
-  operation_class->categories  = "blur";
-  operation_class->description =
-        _("Performs a naive grayscale2color demosaicing of an image, no interpolation.");
+  gegl_operation_class_set_keys (operation_class,
+  "name"        , "gegl:demosaic-simple",
+  "categories"  , "blur",
+  "description" ,
+        _("Performs a naive grayscale2color demosaicing of an image, no interpolation."),
+        NULL);
 }
 #endif
