@@ -48,7 +48,7 @@ buffer_sample (GeglBuffer *buffer,
   gfloat rgba[4];
   GeglRectangle roi = {x,y,1,1};
 
-  gegl_buffer_get (buffer, 1.0, &roi, babl_format ("RGBA float"), &rgba[0], GEGL_AUTO_ROWSTRIDE);
+  gegl_buffer_get (buffer, &roi, 1.0, babl_format ("RGBA float"), &rgba[0], GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
   return rgba[component];
 }
 
@@ -56,7 +56,8 @@ static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *input,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
   gint        width = MAX(MAX (o->width, o->x0), o->x1);
@@ -131,7 +132,7 @@ process (GeglOperation       *operation,
    cairo_line_to (cr, o->x1, o->y1);
    cairo_stroke (cr);
 
-    gegl_buffer_set (output, NULL, babl_format ("B'aG'aR'aA u8"), buf, GEGL_AUTO_ROWSTRIDE);
+    gegl_buffer_set (output, NULL, 0, babl_format ("B'aG'aR'aA u8"), buf, GEGL_AUTO_ROWSTRIDE);
   }
 
   return TRUE;
@@ -170,12 +171,14 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_required_for_output = get_required_for_output;
   operation_class->get_bounding_box = get_bounding_box;
 
-  operation_class->name        = "gegl:line-profile";
-  operation_class->categories  = "debug";
-  operation_class->description =
-        _("Renders luminance profiles for red green and blue components along"
-          " the specified line in the input buffer, plotted in a buffer of the"
-          " specified size.");
+  gegl_operation_class_set_keys (operation_class,
+    "name"        , "gegl:line-profile",
+    "categories"  , "debug",
+    "description" ,
+          _("Renders luminance profiles for red green and blue components along"
+            " the specified line in the input buffer, plotted in a buffer of the"
+            " specified size."),
+          NULL);
 }
 
 #endif
