@@ -82,7 +82,8 @@ get_bounding_box (GeglOperation *operation)
 static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
   gfloat     *buf;
@@ -116,7 +117,7 @@ process (GeglOperation       *operation,
         }
     }
 
-  gegl_buffer_set (output, NULL, babl_format ("Y float"), buf,
+  gegl_buffer_set (output, NULL, 0, babl_format ("Y float"), buf,
                    GEGL_AUTO_ROWSTRIDE);
   g_free (buf);
 
@@ -137,9 +138,11 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->prepare = prepare;
   operation_class->get_bounding_box = get_bounding_box;
 
-  operation_class->name        = "gegl:mandelbrot";
-  operation_class->categories  = "render";
-  operation_class->description = _("Mandelbrot set renderer.");
+  gegl_operation_class_set_keys (operation_class,
+    "name"        , "gegl:mandelbrot",
+    "categories"  , "render",
+    "description" , _("Mandelbrot set renderer"),
+    NULL);
 }
 
 #endif
