@@ -26,9 +26,9 @@ gegl_chant_double (y1,        _("y1"),  -1000.0, 1000.0, 25.0, "")
 gegl_chant_double (x2,        _("x2"),  -1000.0, 1000.0, 50.0, "")
 gegl_chant_double (y2,        _("y2"),  -1000.0, 1000.0, 50.0, "")
 gegl_chant_color (color1,   _("Color"), "black",
-                  _("one end of gradient"))
+                  _("One end of gradient"))
 gegl_chant_color (color2,   _("Other color"), "white",
-                  _("one end of gradient"))
+                  _("One end of gradient"))
 
 #else
 
@@ -61,7 +61,8 @@ static gboolean
 process (GeglOperation       *operation,
          void                *out_buf,
          glong                n_pixels,
-         const GeglRectangle *roi)
+         const GeglRectangle *roi,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
   gfloat     *out_pixel = out_buf;
@@ -70,8 +71,8 @@ process (GeglOperation       *operation,
   gint        x, y;
   gfloat length = dist (o->x1, o->y1, o->x2, o->y2);
 
-  gegl_color_get_rgba4f (o->color1, color1);
-  gegl_color_get_rgba4f (o->color2, color2);
+  gegl_color_get_pixel (o->color1, babl_format ("RGBA float"), color1);
+  gegl_color_get_pixel (o->color2, babl_format ("RGBA float"), color2);
 
   x= roi->x;
   y= roi->y;
@@ -122,9 +123,11 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->prepare = prepare;
   operation_class->no_cache = TRUE;
 
-  operation_class->name        = "gegl:radial-gradient";
-  operation_class->categories  = "render";
-  operation_class->description = _("radial gradient renderer");
+  gegl_operation_class_set_keys (operation_class,
+    "name"        , "gegl:radial-gradient",
+    "categories"  , "render",
+    "description" , _("Radial gradient renderer"),
+    NULL);
 }
 
 #endif
