@@ -120,7 +120,7 @@ calc_undistorted_coords (gdouble  wx,      gdouble  wy,
 static void
 apply_whirl_pinch (gdouble whirl, gdouble pinch, gdouble radius,
                    gdouble cen_x, gdouble cen_y,
-                   Babl    *format,
+                   const Babl    *format,
                    GeglBuffer *src,
                    GeglRectangle *in_boundary,
                    GeglBuffer *dst,
@@ -163,7 +163,7 @@ apply_whirl_pinch (gdouble whirl, gdouble pinch, gdouble radius,
   } /* for */
 
   /* Store dst pixels. */
-  gegl_buffer_set (dst, roi, format, dst_buf, GEGL_AUTO_ROWSTRIDE);
+  gegl_buffer_set (dst, roi, 0, format, dst_buf, GEGL_AUTO_ROWSTRIDE);
 
   gegl_buffer_flush(dst);
 
@@ -215,23 +215,24 @@ static gboolean
 process (GeglOperation       *operation,
          GeglBuffer          *input,
          GeglBuffer          *output,
-         const GeglRectangle *result)
+         const GeglRectangle *result,
+         gint                 level)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle boundary = gegl_operation_get_bounding_box (operation);
-  Babl *format = babl_format ("RaGaBaA float");
+  const Babl *format = babl_format ("RaGaBaA float");
 
   apply_whirl_pinch (o->whirl,
-                o->pinch,
-                o->radius,
-                boundary.width / 2.0,
-                boundary.height / 2.0,
-		format,
-                input,
-		&boundary,
-                output,
-                &boundary,
-                result);
+                     o->pinch,
+                     o->radius,
+                     boundary.width / 2.0,
+                     boundary.height / 2.0,
+                     format,
+                     input,
+                    &boundary,
+                     output,
+                    &boundary,
+                     result);
   return TRUE;
 }
 
@@ -250,10 +251,12 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_bounding_box = get_bounding_box;
   operation_class->get_required_for_output = get_required_for_output;
 
-  operation_class->name        = "gegl:whirl-pinch";
-  operation_class->categories  = "distort";
-  operation_class->description =
-        _("Applies whirling and pinching on the image");
+  gegl_operation_class_set_keys (operation_class,
+  "name"        , "gegl:whirl-pinch",
+  "categories"  , "distort",
+  "description" ,
+        _("Applies whirling and pinching on the image"),
+        NULL);
 }
 
 #endif
