@@ -28,6 +28,6 @@ TEST ()
   fill_rect (buffer, &roi, 0.2);
 
   print_buffer (buffer);
-  gegl_buffer_destroy (buffer);
+  g_object_unref (buffer);
   test_end ();
 }
