@@ -8,7 +8,7 @@ TEST ()
   buffer2 = gegl_buffer_dup (buffer);
   checkerboard (buffer, 3, 0.0, 1.0);
   print_buffer (buffer);
-  gegl_buffer_destroy (buffer);
-  gegl_buffer_destroy (buffer2);
+  g_object_unref (buffer);
+  g_object_unref (buffer2);
   test_end ();
 }
